==> cmr-client-0.1.0-20170902.044926-7.jar: public/js/out/cmr/client/http/impl.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('cmr.client.http.impl');
goog.require('cljs.core');
goog.require('cljs_http.client');
goog.require('cljs.core.async');
goog.require('cmr.client.common.util');
cmr.client.http.impl.result_xducer = cljs.core.map.call(null,cljs.core.clj__GT_js);
cmr.client.http.impl.result_body_xducer = cljs.core.map.call(null,cljs.core.comp.call(null,cljs.core.clj__GT_js,new cljs.core.Keyword(null,"body","body",-2049205669)));
cmr.client.http.impl.make_channel = (function cmr$client$http$impl$make_channel(client){
if(cljs.core.truth_(cljs.core.get_in.call(null,client,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),new cljs.core.Keyword(null,"return-body?","return-body?",930286761)], null)))){
return cljs.core.async.promise_chan.call(null,cmr.client.http.impl.result_body_xducer);
} else {
return cljs.core.async.promise_chan.call(null,cmr.client.http.impl.result_xducer);
}
});
cmr.client.http.impl.get_default_options = (function cmr$client$http$impl$get_default_options(client){
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"with-credentials?","with-credentials?",-1773202222),false,new cljs.core.Keyword(null,"headers","headers",-835030129),new cljs.core.PersistentArrayMap(null, 1, ["Accept","application/json"], null)], null);
});
cmr.client.http.impl.make_http_options = (function cmr$client$http$impl$make_http_options(client,call_options){
return cljs.core.merge.call(null,cmr.client.http.impl.get_default_options.call(null,client),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"channel","channel",734187692),cmr.client.http.impl.make_channel.call(null,client)], null),new cljs.core.Keyword(null,"http-options","http-options",1919701946).cljs$core$IFn$_invoke$arity$1(client),call_options);
});

/**
* @constructor
 * @implements {cljs.core.IRecord}
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.IHash}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IMeta}
 * @implements {cljs.core.ICloneable}
 * @implements {cljs.core.IPrintWithWriter}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.core.IWithMeta}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cmr.client.http.impl.HTTPClientData = (function (parent_client_options,http_options,__meta,__extmap,__hash){
this.parent_client_options = parent_client_options;
this.http_options = http_options;
this.__meta = __meta;
this.__extmap = __extmap;
this.__hash = __hash;
this.cljs$lang$protocol_mask$partition0$ = 2229667594;
this.cljs$lang$protocol_mask$partition1$ = 139264;
});
cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__28987__auto__,k__28988__auto__){
var self__ = this;
var this__28987__auto____$1 = this;
return this__28987__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,k__28988__auto__,null);
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__28989__auto__,k31548,else__28990__auto__){
var self__ = this;
var this__28989__auto____$1 = this;
var G__31552 = k31548;
var G__31552__$1 = (((G__31552 instanceof cljs.core.Keyword))?G__31552.fqn:null);
switch (G__31552__$1) {
case "parent-client-options":
return self__.parent_client_options;

break;
case "http-options":
return self__.http_options;

break;
default:
return cljs.core.get.call(null,self__.__extmap,k31548,else__28990__auto__);

}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IPrintWithWriter$_pr_writer$arity$3 = (function (this__29001__auto__,writer__29002__auto__,opts__29003__auto__){
var self__ = this;
var this__29001__auto____$1 = this;
var pr_pair__29004__auto__ = ((function (this__29001__auto____$1){
return (function (keyval__29005__auto__){
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,cljs.core.pr_writer,""," ","",opts__29003__auto__,keyval__29005__auto__);
});})(this__29001__auto____$1))
;
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,pr_pair__29004__auto__,"#cmr.client.http.impl.HTTPClientData{",", ","}",opts__29003__auto__,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),self__.parent_client_options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-options","http-options",1919701946),self__.http_options],null))], null),self__.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (G__31547){
var self__ = this;
var G__31547__$1 = this;
return (new cljs.core.RecordIter((0),G__31547__$1,2,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),new cljs.core.Keyword(null,"http-options","http-options",1919701946)], null),(cljs.core.truth_(self__.__extmap)?cljs.core._iterator.call(null,self__.__extmap):cljs.core.nil_iter.call(null))));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IMeta$_meta$arity$1 = (function (this__28985__auto__){
var self__ = this;
var this__28985__auto____$1 = this;
return self__.__meta;
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ICloneable$_clone$arity$1 = (function (this__28982__auto__){
var self__ = this;
var this__28982__auto____$1 = this;
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,self__.__meta,self__.__extmap,self__.__hash));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__28991__auto__){
var self__ = this;
var this__28991__auto____$1 = this;
return (2 + cljs.core.count.call(null,self__.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IHash$_hash$arity$1 = (function (this__28983__auto__){
var self__ = this;
var this__28983__auto____$1 = this;
var h__28801__auto__ = self__.__hash;
if(!((h__28801__auto__ == null))){
return h__28801__auto__;
} else {
var h__28801__auto____$1 = ((function (h__28801__auto__,this__28983__auto____$1){
return (function (coll__28984__auto__){
return (1503257311 ^ cljs.core.hash_unordered_coll.call(null,coll__28984__auto__));
});})(h__28801__auto__,this__28983__auto____$1))
.call(null,this__28983__auto____$1);
self__.__hash = h__28801__auto____$1;

return h__28801__auto____$1;
}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this31549,other31550){
var self__ = this;
var this31549__$1 = this;
return (!((other31550 == null))) && ((this31549__$1.constructor === other31550.constructor)) && (cljs.core._EQ_.call(null,this31549__$1.parent_client_options,other31550.parent_client_options)) && (cljs.core._EQ_.call(null,this31549__$1.http_options,other31550.http_options)) && (cljs.core._EQ_.call(null,this31549__$1.__extmap,other31550.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__28996__auto__,k__28997__auto__){
var self__ = this;
var this__28996__auto____$1 = this;
if(cljs.core.contains_QMARK_.call(null,new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),null,new cljs.core.Keyword(null,"http-options","http-options",1919701946),null], null), null),k__28997__auto__)){
return cljs.core.dissoc.call(null,cljs.core._with_meta.call(null,cljs.core.into.call(null,cljs.core.PersistentArrayMap.EMPTY,this__28996__auto____$1),self__.__meta),k__28997__auto__);
} else {
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,self__.__meta,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,self__.__extmap,k__28997__auto__)),null));
}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__28994__auto__,k__28995__auto__,G__31547){
var self__ = this;
var this__28994__auto____$1 = this;
var pred__31553 = cljs.core.keyword_identical_QMARK_;
var expr__31554 = k__28995__auto__;
if(cljs.core.truth_(pred__31553.call(null,new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),expr__31554))){
return (new cmr.client.http.impl.HTTPClientData(G__31547,self__.http_options,self__.__meta,self__.__extmap,null));
} else {
if(cljs.core.truth_(pred__31553.call(null,new cljs.core.Keyword(null,"http-options","http-options",1919701946),expr__31554))){
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,G__31547,self__.__meta,self__.__extmap,null));
} else {
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,self__.__meta,cljs.core.assoc.call(null,self__.__extmap,k__28995__auto__,G__31547),null));
}
}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (this__28999__auto__){
var self__ = this;
var this__28999__auto____$1 = this;
return cljs.core.seq.call(null,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),self__.parent_client_options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-options","http-options",1919701946),self__.http_options],null))], null),self__.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (this__28986__auto__,G__31547){
var self__ = this;
var this__28986__auto____$1 = this;
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,G__31547,self__.__extmap,self__.__hash));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__28992__auto__,entry__28993__auto__){
var self__ = this;
var this__28992__auto____$1 = this;
if(cljs.core.vector_QMARK_.call(null,entry__28993__auto__)){
return this__28992__auto____$1.cljs$core$IAssociative$_assoc$arity$3(null,cljs.core._nth.call(null,entry__28993__auto__,(0)),cljs.core._nth.call(null,entry__28993__auto__,(1)));
} else {
return cljs.core.reduce.call(null,cljs.core._conj,this__28992__auto____$1,entry__28993__auto__);
}
});

cmr.client.http.impl.HTTPClientData.getBasis = (function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Symbol(null,"parent-client-options","parent-client-options",1465001739,null),new cljs.core.Symbol(null,"http-options","http-options",-734733823,null)], null);
});

cmr.client.http.impl.HTTPClientData.cljs$lang$type = true;

cmr.client.http.impl.HTTPClientData.cljs$lang$ctorPrSeq = (function (this__29023__auto__){
return cljs.core._conj.call(null,cljs.core.List.EMPTY,"cmr.client.http.impl/HTTPClientData");
});

cmr.client.http.impl.HTTPClientData.cljs$lang$ctorPrWriter = (function (this__29023__auto__,writer__29024__auto__){
return cljs.core._write.call(null,writer__29024__auto__,"cmr.client.http.impl/HTTPClientData");
});

cmr.client.http.impl.__GT_HTTPClientData = (function cmr$client$http$impl$__GT_HTTPClientData(parent_client_options,http_options){
return (new cmr.client.http.impl.HTTPClientData(parent_client_options,http_options,null,null,null));
});

cmr.client.http.impl.map__GT_HTTPClientData = (function cmr$client$http$impl$map__GT_HTTPClientData(G__31551){
return (new cmr.client.http.impl.HTTPClientData(new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788).cljs$core$IFn$_invoke$arity$1(G__31551),new cljs.core.Keyword(null,"http-options","http-options",1919701946).cljs$core$IFn$_invoke$arity$1(G__31551),null,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,G__31551,new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),new cljs.core.Keyword(null,"http-options","http-options",1919701946))),null));
});

cmr.client.http.impl.get = (function cmr$client$http$impl$get(this$,url,options){
return cljs_http.client.get.call(null,url,cmr.client.http.impl.make_http_options.call(null,this$,options));
});

//# sourceMappingURL=impl.js.map?rel=1504301327818

==> cmr-client-0.1.0-20170903.055506-9.jar: public/js/out/cmr/client/http/impl.js <==
// Compiled by ClojureScript 1.9.908 {}
goog.provide('cmr.client.http.impl');
goog.require('cljs.core');
goog.require('cljs_http.client');
goog.require('cljs.core.async');
goog.require('cmr.client.common.util');
/**
 * Default HTTP client options.
 */
cmr.client.http.impl.default_options = new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"with-credentials?","with-credentials?",-1773202222),false,new cljs.core.Keyword(null,"headers","headers",-835030129),new cljs.core.PersistentArrayMap(null, 1, ["Accept","application/json"], null)], null);
/**
 * A transducer for use with the HTTP client that is used to transform inputs
 *   from Clojure data structures to JavaScript ones.
 */
cmr.client.http.impl.result_xducer = cljs.core.map.call(null,cljs.core.clj__GT_js);
/**
 * A transducer for use with the HTTP client that is used to extract the body
 *   from the inputs and transform it from a Clojure data structure to JavaScript
 *   one.
 */
cmr.client.http.impl.result_body_xducer = cljs.core.map.call(null,cljs.core.comp.call(null,cljs.core.clj__GT_js,new cljs.core.Keyword(null,"body","body",-2049205669)));
/**
 * Create a promise channel used by the third-party HTTP client library to
 *   receive responses.
 */
cmr.client.http.impl.create_channel = (function cmr$client$http$impl$create_channel(client){
if(cljs.core.truth_(cljs.core.get_in.call(null,client,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),new cljs.core.Keyword(null,"return-body?","return-body?",930286761)], null)))){
return cljs.core.async.promise_chan.call(null,cmr.client.http.impl.result_body_xducer);
} else {
return cljs.core.async.promise_chan.call(null,cmr.client.http.impl.result_xducer);
}
});
/**
 * This function is intended to be used with every call, giving the call the
 *   opportunity to override the HTTP client options saved when the client was
 *   instantiated.
 */
cmr.client.http.impl.create_http_options = (function cmr$client$http$impl$create_http_options(client,call_options){
return cljs.core.merge.call(null,cmr.client.http.impl.default_options,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"channel","channel",734187692),cmr.client.http.impl.create_channel.call(null,client)], null),new cljs.core.Keyword(null,"http-options","http-options",1919701946).cljs$core$IFn$_invoke$arity$1(client),call_options);
});

/**
* @constructor
 * @implements {cljs.core.IRecord}
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.IHash}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IMeta}
 * @implements {cljs.core.ICloneable}
 * @implements {cljs.core.IPrintWithWriter}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.core.IWithMeta}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cmr.client.http.impl.HTTPClientData = (function (parent_client_options,http_options,__meta,__extmap,__hash){
this.parent_client_options = parent_client_options;
this.http_options = http_options;
this.__meta = __meta;
this.__extmap = __extmap;
this.__hash = __hash;
this.cljs$lang$protocol_mask$partition0$ = 2229667594;
this.cljs$lang$protocol_mask$partition1$ = 139264;
});
cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__28987__auto__,k__28988__auto__){
var self__ = this;
var this__28987__auto____$1 = this;
return this__28987__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,k__28988__auto__,null);
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__28989__auto__,k37834,else__28990__auto__){
var self__ = this;
var this__28989__auto____$1 = this;
var G__37838 = k37834;
var G__37838__$1 = (((G__37838 instanceof cljs.core.Keyword))?G__37838.fqn:null);
switch (G__37838__$1) {
case "parent-client-options":
return self__.parent_client_options;

break;
case "http-options":
return self__.http_options;

break;
default:
return cljs.core.get.call(null,self__.__extmap,k37834,else__28990__auto__);

}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IPrintWithWriter$_pr_writer$arity$3 = (function (this__29001__auto__,writer__29002__auto__,opts__29003__auto__){
var self__ = this;
var this__29001__auto____$1 = this;
var pr_pair__29004__auto__ = ((function (this__29001__auto____$1){
return (function (keyval__29005__auto__){
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,cljs.core.pr_writer,""," ","",opts__29003__auto__,keyval__29005__auto__);
});})(this__29001__auto____$1))
;
return cljs.core.pr_sequential_writer.call(null,writer__29002__auto__,pr_pair__29004__auto__,"#cmr.client.http.impl.HTTPClientData{",", ","}",opts__29003__auto__,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),self__.parent_client_options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-options","http-options",1919701946),self__.http_options],null))], null),self__.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (G__37833){
var self__ = this;
var G__37833__$1 = this;
return (new cljs.core.RecordIter((0),G__37833__$1,2,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),new cljs.core.Keyword(null,"http-options","http-options",1919701946)], null),(cljs.core.truth_(self__.__extmap)?cljs.core._iterator.call(null,self__.__extmap):cljs.core.nil_iter.call(null))));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IMeta$_meta$arity$1 = (function (this__28985__auto__){
var self__ = this;
var this__28985__auto____$1 = this;
return self__.__meta;
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ICloneable$_clone$arity$1 = (function (this__28982__auto__){
var self__ = this;
var this__28982__auto____$1 = this;
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,self__.__meta,self__.__extmap,self__.__hash));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__28991__auto__){
var self__ = this;
var this__28991__auto____$1 = this;
return (2 + cljs.core.count.call(null,self__.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IHash$_hash$arity$1 = (function (this__28983__auto__){
var self__ = this;
var this__28983__auto____$1 = this;
var h__28801__auto__ = self__.__hash;
if(!((h__28801__auto__ == null))){
return h__28801__auto__;
} else {
var h__28801__auto____$1 = ((function (h__28801__auto__,this__28983__auto____$1){
return (function (coll__28984__auto__){
return (1503257311 ^ cljs.core.hash_unordered_coll.call(null,coll__28984__auto__));
});})(h__28801__auto__,this__28983__auto____$1))
.call(null,this__28983__auto____$1);
self__.__hash = h__28801__auto____$1;

return h__28801__auto____$1;
}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this37835,other37836){
var self__ = this;
var this37835__$1 = this;
return (!((other37836 == null))) && ((this37835__$1.constructor === other37836.constructor)) && (cljs.core._EQ_.call(null,this37835__$1.parent_client_options,other37836.parent_client_options)) && (cljs.core._EQ_.call(null,this37835__$1.http_options,other37836.http_options)) && (cljs.core._EQ_.call(null,this37835__$1.__extmap,other37836.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__28996__auto__,k__28997__auto__){
var self__ = this;
var this__28996__auto____$1 = this;
if(cljs.core.contains_QMARK_.call(null,new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),null,new cljs.core.Keyword(null,"http-options","http-options",1919701946),null], null), null),k__28997__auto__)){
return cljs.core.dissoc.call(null,cljs.core._with_meta.call(null,cljs.core.into.call(null,cljs.core.PersistentArrayMap.EMPTY,this__28996__auto____$1),self__.__meta),k__28997__auto__);
} else {
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,self__.__meta,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,self__.__extmap,k__28997__auto__)),null));
}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__28994__auto__,k__28995__auto__,G__37833){
var self__ = this;
var this__28994__auto____$1 = this;
var pred__37839 = cljs.core.keyword_identical_QMARK_;
var expr__37840 = k__28995__auto__;
if(cljs.core.truth_(pred__37839.call(null,new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),expr__37840))){
return (new cmr.client.http.impl.HTTPClientData(G__37833,self__.http_options,self__.__meta,self__.__extmap,null));
} else {
if(cljs.core.truth_(pred__37839.call(null,new cljs.core.Keyword(null,"http-options","http-options",1919701946),expr__37840))){
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,G__37833,self__.__meta,self__.__extmap,null));
} else {
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,self__.__meta,cljs.core.assoc.call(null,self__.__extmap,k__28995__auto__,G__37833),null));
}
}
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (this__28999__auto__){
var self__ = this;
var this__28999__auto____$1 = this;
return cljs.core.seq.call(null,cljs.core.concat.call(null,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),self__.parent_client_options],null)),(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"http-options","http-options",1919701946),self__.http_options],null))], null),self__.__extmap));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (this__28986__auto__,G__37833){
var self__ = this;
var this__28986__auto____$1 = this;
return (new cmr.client.http.impl.HTTPClientData(self__.parent_client_options,self__.http_options,G__37833,self__.__extmap,self__.__hash));
});

cmr.client.http.impl.HTTPClientData.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__28992__auto__,entry__28993__auto__){
var self__ = this;
var this__28992__auto____$1 = this;
if(cljs.core.vector_QMARK_.call(null,entry__28993__auto__)){
return this__28992__auto____$1.cljs$core$IAssociative$_assoc$arity$3(null,cljs.core._nth.call(null,entry__28993__auto__,(0)),cljs.core._nth.call(null,entry__28993__auto__,(1)));
} else {
return cljs.core.reduce.call(null,cljs.core._conj,this__28992__auto____$1,entry__28993__auto__);
}
});

cmr.client.http.impl.HTTPClientData.getBasis = (function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Symbol(null,"parent-client-options","parent-client-options",1465001739,null),new cljs.core.Symbol(null,"http-options","http-options",-734733823,null)], null);
});

cmr.client.http.impl.HTTPClientData.cljs$lang$type = true;

cmr.client.http.impl.HTTPClientData.cljs$lang$ctorPrSeq = (function (this__29023__auto__){
return cljs.core._conj.call(null,cljs.core.List.EMPTY,"cmr.client.http.impl/HTTPClientData");
});

cmr.client.http.impl.HTTPClientData.cljs$lang$ctorPrWriter = (function (this__29023__auto__,writer__29024__auto__){
return cljs.core._write.call(null,writer__29024__auto__,"cmr.client.http.impl/HTTPClientData");
});

cmr.client.http.impl.__GT_HTTPClientData = (function cmr$client$http$impl$__GT_HTTPClientData(parent_client_options,http_options){
return (new cmr.client.http.impl.HTTPClientData(parent_client_options,http_options,null,null,null));
});

cmr.client.http.impl.map__GT_HTTPClientData = (function cmr$client$http$impl$map__GT_HTTPClientData(G__37837){
return (new cmr.client.http.impl.HTTPClientData(new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788).cljs$core$IFn$_invoke$arity$1(G__37837),new cljs.core.Keyword(null,"http-options","http-options",1919701946).cljs$core$IFn$_invoke$arity$1(G__37837),null,cljs.core.not_empty.call(null,cljs.core.dissoc.call(null,G__37837,new cljs.core.Keyword(null,"parent-client-options","parent-client-options",-175529788),new cljs.core.Keyword(null,"http-options","http-options",1919701946))),null));
});

/**
 * Perform an HTTP `GET`.
 */
cmr.client.http.impl.get = (function cmr$client$http$impl$get(this$,url,options){
return cljs_http.client.get.call(null,url,cmr.client.http.impl.create_http_options.call(null,this$,options));
});

//# sourceMappingURL=impl.js.map?rel=1504416267266
